from selenium import webdriver
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
import time
import pickle

# --- Browser-Konfiguration für Brave (sichtbarer Modus) ---
chrome_options = Options()
chrome_options.binary_location = '/usr/bin/brave-browser'
chrome_options.add_argument("--no-sandbox")
chrome_options.add_argument("--disable-dev-shm-usage")
chrome_options.add_argument("--disable-setuid-sandbox")
service = Service('/usr/local/bin/chromedriver')

driver = webdriver.Chrome(service=service, options=chrome_options)
wait = WebDriverWait(driver, 20)

# --- 1) Manueller Login & Cookies speichern ---
driver.get("https://account.komoot.com/signin")
print("Bitte manuell bei Komoot anmelden und dann Enter drücken …")
input()
with open("komoot_cookies.pkl", "wb") as f:
    pickle.dump(driver.get_cookies(), f)

# --- 2) Zur Aktivitäten‑Übersicht navigieren ---
activities_url = "https://www.komoot.com/de-de/user/hier-die-user-id-eingeben/activities"
driver.get(activities_url)
time.sleep(5)  # Warte, bis die Seite geladen ist

# --- 3) Aktivitäten der Reihe nach löschen ---
while True:
    try:
        # Finde den obersten "Löschen"-Button
        delete_btn = wait.until(EC.element_to_be_clickable(
            (By.CSS_SELECTOR, "button[data-test-id='t_actions_delete']")
        ))
    except:
        print("Keine weiteren Aktivitäten gefunden. Fertig.")
        break

    # Scroll zur Schaltfläche und klicke
    driver.execute_script("arguments[0].scrollIntoView({block: 'center'});", delete_btn)
    time.sleep(0.3)
    delete_btn.click()
    print("→ Klick auf Löschen‑Button")

    # Warte auf das Overlay und bestätige das Löschen
    try:
        confirm_btn = wait.until(EC.element_to_be_clickable(
            (By.CSS_SELECTOR, "button[data-test-id='t_actions_delete_confirm']")
        ))
        confirm_btn.click()
        print("→ Bestätigungs‑Button im Overlay geklickt")
    except:
        print("→ Bestätigungs‑Overlay nicht gefunden")

    # Warte kurz, bis die Seite die gelöschte Aktivität entfernt hat
    time.sleep(2)

print("Alle Aktionen abgeschlossen.")
driver.quit()
